Network transformation and mapping
==================================

.. toctree::
   :maxdepth: 1

   mapper
   lut_mapping
   collapse_mapped
   node_resynthesis
   klut_to_graph
   cover_to_graph
   gates_to_nodes
   cleanup
   equivalence_classes
   buffer_insertion
   retiming